@@ -194,12 +194,12 @@ class Puppet::Configurer
   # This just passes any options on to the catalog,
   # which accepts :tags and :ignoreschedules.
   def run(options = {})
-    pool = Puppet.runtime['http'].pool
+    pool = Puppet.runtime[:http].pool
     # We create the report pre-populated with default settings for
     # environment and transaction_uuid very early, this is to ensure
     # they are sent regardless of any catalog compilation failures or
     # exceptions.
-    options[:report] ||= Puppet::Transaction::Report.new(nil, @environment, @transaction_uuid, @job_id)
+    options[:report] ||= Puppet::Transaction::Report.new(nil, @environment, @transaction_uuid, @job_id, options[:start_time] || Time.now)
     report = options[:report]
     init_storage
 
@@ -235,9 +235,13 @@ class Puppet::Configurer
   end
 
   def run_internal(options)
-    start = Time.now
     report = options[:report]
 
+    if options[:start_time]
+      startup_time = Time.now - options[:start_time]
+      report.add_times(:startup_time, startup_time)
+    end
+
     # If a cached catalog is explicitly requested, attempt to retrieve it. Skip the node request,
     # don't pluginsync and switch to the catalog's environment if we successfully retrieve it.
     if Puppet[:use_cached_catalog]
@@ -402,7 +406,7 @@ class Puppet::Configurer
     end
 
     report.cached_catalog_status ||= @cached_catalog_status
-    report.add_times(:total, Time.now - start)
+    report.add_times(:total, Time.now - report.time)
     report.finalize_report
     Puppet::Util::Log.close(report)
     send_report(report)
@@ -455,7 +459,7 @@ class Puppet::Configurer
     ::Facter.clear
     facts = find_facts
 
-    client = Puppet.runtime['http']
+    client = Puppet.runtime[:http]
     session = client.create_session
     puppet = session.route_to(:puppet)
 
