@@ -51,7 +51,11 @@ module Puppet
       desc "Whether a service should be enabled to start at boot.
         This property behaves differently depending on the platform;
         wherever possible, it relies on local tools to enable or disable
-        a given service. Default values depend on the platform."
+        a given service. Default values depend on the platform.
+        
+        If you don't specify a value for the `enable` attribute, Puppet leaves
+        that aspect of the service alone and your operating system determines 
+        the behavior."
 
       newvalue(:true, :event => :service_enabled) do
         provider.enable
@@ -80,14 +84,8 @@ module Puppet
         provider.delayed_start
       end
 
-      # This only makes sense on systemd systems. Static services cannot be enabled
-      # or disabled manually.
       def insync?(current)
-        if provider.respond_to?(:cached_enabled?) && provider.cached_enabled? == 'static'
-          Puppet.debug("Unable to enable or disable static service #{@resource[:name]}")
-          return true
-        end
-
+        return provider.enabled_insync?(current) if provider.respond_to?(:enabled_insync?)
         super(current)
       end
 
